==> kadu-0.3.9.tar.bz2: kadu/modules/speech/translations/speech_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Notify by speech</source>
        <translation>Benachrichtige mit Sprache</translation>
    </message>
    <message>
        <source>Speech</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Say only when chat window is not active</source>
        <translation>Sag nur, wenn das Chat-Fenster nicht aktiv ist</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Standardfrequenz</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Tonfall</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation></translation>
    </message>
    <message>
        <source>Use aRts</source>
        <translation>Benutze aRTs</translation>
    </message>
    <message>
        <source>Use Esd</source>
        <translation>Benutze Esd</translation>
    </message>
    <message>
        <source>Use Dsp</source>
        <translation>Benutze Dsp</translation>
    </message>
    <message>
        <source>Dsp device:</source>
        <translation>Gerät Dsp:</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>Programm</translation>
    </message>
    <message>
        <source>Speech program:</source>
        <translation>Lese-Programm:</translation>
    </message>
    <message>
        <source>Chat format (male):</source>
        <translation>Chat-Format (männlich):</translation>
    </message>
    <message>
        <source>Chat format (female):</source>
        <translation>Chat-Format (weiblich):</translation>
    </message>
    <message>
        <source>Message format (male):</source>
        <translation>Nachrichten-Format (männlich):</translation>
    </message>
    <message>
        <source>Message format (female):</source>
        <translation>Nachrichten-Format (weiblich):</translation>
    </message>
    <message>
        <source>Notify format (male):</source>
        <translation>Benachrichtigung (männlich):</translation>
    </message>
    <message>
        <source>Notify format (female):</source>
        <translation>Benachrichtigung (weiblich):</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
</context>
<context>
    <name>SpeechSlots</name>
    <message>
        <source>man %a said %1</source>
        <translation>Mann %a sagt%1</translation>
    </message>
    <message>
        <source>woman %a said %1</source>
        <translation>Frau %a sagt %1</translation>
    </message>
    <message>
        <source>man %a changed status to %s %d</source>
        <translation>Mann %a ändert Status auf %s %d</translation>
    </message>
    <message>
        <source>woman %a changed status to %s %d</source>
        <translation>Frau %a ändert Status auf %s %d</translation>
    </message>
</context>
</TS>

==> kadu-0.4.1.tar.bz2: kadu/modules/speech/translations/speech_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Speech</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <source>Say only when chat window is not active</source>
        <translation>Sag nur, wenn das Chat-Fenster nicht aktiv ist</translation>
    </message>
    <message>
        <source>Frequency</source>
        <translation>Frequenz</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <source>Base frequency</source>
        <translation>Standardfrequenz</translation>
    </message>
    <message>
        <source>Melody</source>
        <translation>Tonfall</translation>
    </message>
    <message>
        <source>Klatt synthesizer (requires dsp)</source>
        <translation>Klatt-Sprachausgabe (benutzt dsp)</translation>
    </message>
    <message>
        <source>Use aRts</source>
        <translation>Benutze aRTs</translation>
    </message>
    <message>
        <source>Use Esd</source>
        <translation>Benutze Esd</translation>
    </message>
    <message>
        <source>Use Dsp</source>
        <translation>Benutze dsp</translation>
    </message>
    <message>
        <source>Dsp device:</source>
        <translation>Gerät dsp:</translation>
    </message>
    <message>
        <source>Program</source>
        <translation>Programm</translation>
    </message>
    <message>
        <source>Speech program:</source>
        <translation>Lese-Programm:</translation>
    </message>
    <message>
        <source>Chat format (male):</source>
        <translation>Chat-Format (männlich):</translation>
    </message>
    <message>
        <source>Chat format (female):</source>
        <translation>Chat-Format (weiblich):</translation>
    </message>
    <message>
        <source>Message format (male):</source>
        <translation>Nachrichten-Format (männlich):</translation>
    </message>
    <message>
        <source>Message format (female):</source>
        <translation>Nachrichten-Format (weiblich):</translation>
    </message>
    <message>
        <source>Notify format (male):</source>
        <translation>Benachrichtigung (männlich):</translation>
    </message>
    <message>
        <source>Notify format (female):</source>
        <translation>Benachrichtigung (weiblich):</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Connection error:</source>
        <translation>Verbindungsfehler:</translation>
    </message>
    <message>
        <source>Maximum number of spoken letters</source>
        <translation>Maximalzahl der gesprochenen Buchstaben</translation>
    </message>
    <message>
        <source>Message too long (male):</source>
        <translation>Nachricht zu lang (männlich):</translation>
    </message>
    <message>
        <source>Message too long (female):</source>
        <translation>Nachricht zu lang (weiblich):</translation>
    </message>
</context>
<context>
    <name>SpeechSlots</name>
    <message>
        <source>man %a changed status to %s %d</source>
        <translation>Mann %a ändert Status auf %s %d</translation>
    </message>
    <message>
        <source>woman %a changed status to %s %d</source>
        <translation>Frau %a ändert Status auf %s %d</translation>
    </message>
    <message>
        <source>Connection error - %1</source>
        <translation>Verbindungsfehler - %1</translation>
    </message>
    <message>
        <source>man %a wrote %1</source>
        <translation>Herr %a schrieb %1</translation>
    </message>
    <message>
        <source>woman %a wrote %1</source>
        <translation>Frau %a schieb %1</translation>
    </message>
    <message>
        <source>%a wrote long message</source>
        <translation>%a schrieb zu lange Nachricht</translation>
    </message>
</context>
</TS>
